@@ -1,18 +1,27 @@
 package Database::Migrator;
-$Database::Migrator::VERSION = '0.11';
+
+use strict;
+use warnings;
+
+our $VERSION = '0.12';
+
+1;
+
 # ABSTRACT: A system for implementing database migrations
 
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Database::Migrator - A system for implementing database migrations
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 DESCRIPTION
 
@@ -190,13 +199,35 @@ Please submit bugs to the CPAN RT system at
 http://rt.cpan.org/NoAuth/Bugs.html?Dist=Database-Migrator or via email at
 bug-database-migrator@rt.cpan.org.
 
+Bugs may be submitted through L<https://github.com/maxmind/Database-Migrator/issues>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Gregory Oschwald Kevin Phair Olaf Alders
+
+=over 4
+
+=item *
+
+Gregory Oschwald <goschwald@maxmind.com>
+
+=item *
+
+Kevin Phair <phair.kevin@gmail.com>
+
+=item *
+
+Olaf Alders <olaf@wundersolutions.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by MaxMind, Inc..
+This software is Copyright (c) 2012 - 2017 by MaxMind, Inc.
 
 This is free software, licensed under:
 
