@@ -1,15 +1,18 @@
 package Database::Migrator::Core;
-$Database::Migrator::Core::VERSION = '0.11';
+
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.12';
+
 use Database::Migrator::Types qw( ArrayRef Bool Dir File Maybe Str );
 use DBI;
 use Eval::Closure qw( eval_closure );
-use File::Slurp qw( read_file );
 use Log::Dispatch;
 use Moose::Util::TypeConstraints qw( duck_type );
+use MooseX::Getopt::OptionTypeMap;
+use Try::Tiny;
 
 use Moose::Role;
 
@@ -176,7 +179,7 @@ sub _run_one_migration {
         else {
             $self->logger()->debug(" - running $basename as perl code");
 
-            my $perl = read_file( $file->stringify() );
+            my $perl = $file->slurp();
 
             my $sub = eval_closure( source => $perl );
 
@@ -189,7 +192,8 @@ sub _run_one_migration {
     return if $self->dry_run();
 
     my $table = $self->dbh()->quote_identifier( $self->migration_table() );
-    $self->dbh()->do( "INSERT INTO $table (migration) VALUES (?)", undef, $name );
+    $self->dbh()
+        ->do( "INSERT INTO $table (migration) VALUES (?)", undef, $name );
 
     return;
 }
@@ -234,8 +238,8 @@ sub _build_logger {
 sub _build_database_exists {
     my $self = shift;
 
-    local $@;
-    return eval { $self->_build_dbh() } ? 1 : 0;
+    ## no critic (RequireBlockTermination)
+    return try { $self->_build_dbh(); 1 } || 0;
 }
 
 sub _build_dbh {
@@ -244,8 +248,7 @@ sub _build_dbh {
     return DBI->connect(
         'dbi:' . $self->_driver_name() . ':database=' . $self->database(),
         $self->username(),
-        $self->password(),
-        {
+        $self->password(), {
             RaiseError         => 1,
             PrintError         => 1,
             PrintWarn          => 1,
@@ -264,7 +267,6 @@ sub _numeric_or_alpha_sort {
     return ( $a_num <=> $b_num or $a_alpha cmp $b_alpha );
 }
 
-
 1;
 
 # ABSTRACT: Core role for Database::Migrator implementation classes
@@ -273,13 +275,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Database::Migrator::Core - Core role for Database::Migrator implementation classes
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -288,9 +292,9 @@ version 0.11
   use Moose;
   with 'Database::Migrator::Core';
 
-  sub _build_database_exists { ... }
-  sub _build_dbh             { ... }
-  sub _create_database       { ... }
+  sub _build_database_exists { }
+  sub _build_dbh             { }
+  sub _create_database       { }
 
 =head1 DESCRIPTION
 
@@ -416,13 +420,17 @@ You must return an object with C<debug()> and C<info()> methods.
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/Database-Migrator/issues>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by MaxMind, Inc..
+This software is Copyright (c) 2012 - 2017 by MaxMind, Inc.
 
 This is free software, licensed under:
 
