@@ -1,8 +1,11 @@
 package Test::Database::Migrator;
-$Test::Database::Migrator::VERSION = '0.11';
+
 use strict;
 use warnings;
 use namespace::autoclean;
+use autodie;
+
+our $VERSION = '0.12';
 
 use File::Temp qw( tempdir );
 use Database::Migrator::Types qw( ClassName Dir File Str );
@@ -79,7 +82,8 @@ sub _write_ddl_file {
     my $ddl  = shift;
 
     open my $fh, '>', $file;
-    print {$fh} $ddl;
+    print {$fh} $ddl
+        or die $!;
     close $fh;
 }
 
@@ -167,7 +171,9 @@ sub _write_first_migration {
     my $self = shift;
 
     my $dir = $self->_migrations_dir()->subdir('01-first');
+    ## no critic (Lax::ProhibitLeadingZeros::ExceptChmod, ValuesAndExpressions::ProhibitLeadingZeros)
     $dir->mkpath( 0, 0755 );
+    ## use critic
 
     my $create_tables = <<'EOF';
 CREATE TABLE bar (
@@ -198,10 +204,12 @@ sub _write_second_migration {
     my $self = shift;
 
     my $dir = $self->_migrations_dir()->subdir('02-second');
+    ## no critic (Lax::ProhibitLeadingZeros::ExceptChmod, ValuesAndExpressions::ProhibitLeadingZeros)
     $dir->mkpath( 0, 0755 );
+    ## use critic
 
     open my $fh, '>', $dir->file('01-create-baz-table-index.sql');
-    print {$fh} <<'EOF';
+    print {$fh} <<'EOF' or die $!;
 CREATE INDEX baz_baz_name ON baz (baz_name);
 EOF
     close $fh;
@@ -231,7 +239,9 @@ sub _build_migrations_dir {
     my $self = shift;
 
     my $dir = $self->_tempdir()->subdir('migrations');
+    ## no critic (Lax::ProhibitLeadingZeros::ExceptChmod, ValuesAndExpressions::ProhibitLeadingZeros)
     $dir->mkpath( 0, 0755 );
+    ## use critic
 
     return $dir;
 }
@@ -246,7 +256,9 @@ sub DEMOLISH {
     my $self = shift;
 
     if ( $ENV{DATABASE_MIGRATOR_TEST_WAIT} ) {
-        print "\n  Waiting to clean up the test database\n\n";
+        print "\n  Waiting to clean up the test database\n\n"
+            or die $!;
+        ## no critic (InputOutput::ProhibitExplicitStdin)
         my $x = <STDIN>;
     }
 
